==> 0.0.32.tar.gz: lib/nui_date_picker.dart <==
import 'package:date_util/date_util.dart';
import 'package:flutter/cupertino.dart';
import 'package:nui_core/nui_core.dart';

typedef DOBSelectListener = DateTime Function();
class DOBPickerController{
  DOBPickerController({this.valueChangedListener});
  DOBSelectListener _listener;
  Function valueChangedListener;

  DateTime getDateOfBirth(){
    return _listener();
  }

  void _valueChanged(){
    if(valueChangedListener != null) valueChangedListener();
  }
}

class DOBPicker extends StatefulWidget {
  DOBPicker({this.controller, this.textStyle, this.lineColor, this.isDateOfBirth : false, this.shortMonth: true, this.yearsRange: 100, this.height: 160, this.itemExtent: 64});
  static const MONTHS = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"];
  static const MONTHS_SHORT = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
  final DOBPickerController controller;
  final TextStyle textStyle;
  final Color lineColor;
  final bool isDateOfBirth;
  final bool shortMonth;
  final int yearsRange;
  final double height;
  final double itemExtent;

  @override
  _DOBPickerState createState() => _DOBPickerState();
}

class _DOBPickerState extends State<DOBPicker> {
  int _selectedYear;
  int _selectedMonth;
  int _selectedDay;

  int _prevSelectedMonth;
  int _prevSelectedYear;
  DOBPickerController _controller;
  FixedExtentScrollController dayController = FixedExtentScrollController(initialItem: 0);

  List<int> _getYearsSelection(){
    final currentYear = DateTime.now().year;
    List<int> years = List();
    final diffYear = widget.yearsRange ?? 100;
    for(int i = 0; i< diffYear; i++){
      years.add(currentYear - (diffYear - i));
    }
    years.add(currentYear);

    if(widget.isDateOfBirth != true) {
      for(int i = 1; i< diffYear; i++){
        years.add(currentYear + i);
      }
    }
    return years;
  }

  List<int> _getDaysInMonthYear(int month, int year){
    final days = DateUtil().daysInMonth(month, year);
    final daysSelection = List<int>();
    for(int i = 1; i<= days; i++){
      daysSelection.add(i);
    }
    return daysSelection;
  }

  @override
  void initState(){
    super.initState();
    final curDate = DateTime.now();
    _selectedDay = 1;
    _selectedMonth = 1;
    _prevSelectedMonth = 1;
    _selectedYear = curDate.year - 20;
    _prevSelectedYear = curDate.year - 20;
    _controller = widget.controller ?? DOBPickerController();
    _controller._listener = (){
      return DateTime(_selectedYear, _selectedMonth, _selectedDay);
    };
  }

  void _updateSelectedDayOnMonthChange() async{
    final daysCur = DateUtil().daysInMonth(_selectedMonth, _selectedYear);
    final daysPrev = DateUtil().daysInMonth(_prevSelectedMonth, _selectedYear);

    if(_selectedDay == daysPrev){
      _selectedDay = daysCur;
      dayController.animateToItem(_selectedDay - 1, duration: Duration(milliseconds: 250), curve: Curves.ease);
    }

  }

  @override
  Widget build(BuildContext context) {

    final yearsSelection = _getYearsSelection();
    final curYearIndex = yearsSelection.indexOf(_selectedYear);
    final curMonthIndex = _selectedMonth - 1;
    final curDayIndex = _selectedDay - 1;

    return Container(
      width: double.infinity,
      height: widget.height,
      child: Stack(
        children: [
          Container(
            height: 160,
            width: double.infinity,
            alignment: Alignment.center,
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Expanded(
                  child: CupertinoPicker(
                      itemExtent: widget.itemExtent,
                      scrollController: dayController,
                      magnification: 1,
                      onSelectedItemChanged: (position){
                        _selectedDay = position + 1;
                        widget.controller._valueChanged();
                      },
                      children: _getDaysInMonthYear(_selectedMonth, _selectedDay).map((e) {
                        return Center(child: Text(e.toString(), style: widget.textStyle ?? getFont(context, size: 24, singleColor: NUIColors.NUIWhite)));
                      }).toList()
                  ),
                ),
                Expanded(
                  child: CupertinoPicker(
                      scrollController: FixedExtentScrollController(initialItem: curMonthIndex),
                      itemExtent: widget.itemExtent,
                      magnification: 1,
                      onSelectedItemChanged: (position){
                        setState(() {
                          _prevSelectedMonth = _selectedMonth;
                          _selectedMonth = position + 1;
                          _updateSelectedDayOnMonthChange();
                          widget.controller._valueChanged();
                        });
                      },
                      children: (widget.shortMonth == true ? DOBPicker.MONTHS_SHORT : DOBPicker.MONTHS).map((e) {
                        return Center(child: Text(e.toString(), style: widget.textStyle ?? getFont(context, size: 24, singleColor: NUIColors.NUIWhite)));
                      }).toList()
                  ),
                ),
                Expanded(
                  child: CupertinoPicker(
                      scrollController: FixedExtentScrollController(initialItem: curYearIndex),
                      itemExtent: widget.itemExtent,
                      magnification: 1,
                      onSelectedItemChanged: (position){
                        setState(() {
                          _prevSelectedYear = _selectedYear;
                          _selectedYear = yearsSelection[position];
                          _updateSelectedDayOnMonthChange();
                          widget.controller._valueChanged();
                        });
                      },
                      children: yearsSelection.map((e) {
                        return Center(child: Text(e.toString(), style: widget.textStyle ?? getFont(context, size: 24, singleColor: NUIColors.NUIWhite)));
                      }).toList()
                  ),
                ),
              ],
            ),
          ),
          Container(
            margin: EdgeInsets.only(top: (widget.height - widget.itemExtent)/2),
            width: double.infinity,
            height: 1,
            color: widget.lineColor ?? NUIColors.NUIWhite.withOpacity(0.5),
          ),
          Container(
            margin: EdgeInsets.only(top: widget.height - (widget.height - widget.itemExtent)/2),
            width: double.infinity,
            height: 1,
            color: widget.lineColor ?? NUIColors.NUIWhite.withOpacity(0.5),
          )
        ],
      ),
    );
  }
}

==> 0.0.48.tar.gz: lib/nui_date_picker.dart <==
import 'package:date_util/date_util.dart';
import 'package:flutter/cupertino.dart';
import 'package:nui_core/nui_core.dart';

typedef DOBSelectListener = DateTime Function();
class DOBPickerController{
  DOBPickerController({this.valueChangedListener});
  DOBSelectListener _listener;
  Function valueChangedListener;

  DateTime getDateOfBirth(){
    return _listener();
  }

  void _valueChanged(){
    if(valueChangedListener != null) valueChangedListener();
  }
}

class DOBPicker extends StatefulWidget {
  DOBPicker({this.controller, this.textStyle, this.lineColor, this.isDateOfBirth : false, this.shortMonth: true, this.yearsRange: 100, this.height: 160, this.itemExtent: 64});
  static const MONTHS = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"];
  static const MONTHS_SHORT = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
  final DOBPickerController controller;
  final TextStyle textStyle;
  final Color lineColor;
  final bool isDateOfBirth;
  final bool shortMonth;
  final int yearsRange;
  final double height;
  final double itemExtent;

  @override
  _DOBPickerState createState() => _DOBPickerState();
}

class _DOBPickerState extends State<DOBPicker> {
  int _selectedYear;
  int _selectedMonth;
  int _selectedDay;

  int _prevSelectedMonth;
  int _prevSelectedYear;
  DOBPickerController _controller;
  FixedExtentScrollController dayController = FixedExtentScrollController(initialItem: 0);

  List<int> _getYearsSelection(){
    final currentYear = DateTime.now().year;
    List<int> years = List();
    final diffYear = widget.yearsRange ?? 100;
    for(int i = 0; i< diffYear; i++){
      years.add(currentYear - (diffYear - i));
    }
    years.add(currentYear);

    if(widget.isDateOfBirth != true) {
      for(int i = 1; i< diffYear; i++){
        years.add(currentYear + i);
      }
    }
    return years;
  }

  List<int> _getDaysInMonthYear(int month, int year){
    final days = DateUtil().daysInMonth(month, year);
    final daysSelection = <int>[];
    for(int i = 1; i<= days; i++){
      daysSelection.add(i);
    }
    return daysSelection;
  }

  @override
  void initState(){
    super.initState();
    final curDate = DateTime.now();
    _selectedDay = 1;
    _selectedMonth = 1;
    _prevSelectedMonth = 1;
    _selectedYear = curDate.year - 20;
    _prevSelectedYear = curDate.year - 20;
    _controller = widget.controller ?? DOBPickerController();
    _controller._listener = (){
      return DateTime(_selectedYear, _selectedMonth, _selectedDay);
    };
  }

  void _updateSelectedDayOnMonthChange() async{
    final daysCur = DateUtil().daysInMonth(_selectedMonth, _selectedYear);
    final daysPrev = DateUtil().daysInMonth(_prevSelectedMonth, _selectedYear);

    if(_selectedDay == daysPrev){
      _selectedDay = daysCur;
      dayController.animateToItem(_selectedDay - 1, duration: Duration(milliseconds: 250), curve: Curves.ease);
    }

  }

  @override
  Widget build(BuildContext context) {

    final yearsSelection = _getYearsSelection();
    final curYearIndex = yearsSelection.indexOf(_selectedYear);
    final curMonthIndex = _selectedMonth - 1;
    final curDayIndex = _selectedDay - 1;

    return Container(
      width: double.infinity,
      height: widget.height,
      child: Stack(
        children: [
          Container(
            height: 160,
            width: double.infinity,
            alignment: Alignment.center,
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Expanded(
                  child: CupertinoPicker(
                      itemExtent: widget.itemExtent,
                      scrollController: dayController,
                      magnification: 1,
                      onSelectedItemChanged: (position){
                        _selectedDay = position + 1;
                        widget.controller._valueChanged();
                      },
                      children: _getDaysInMonthYear(_selectedMonth, _selectedDay).map((e) {
                        return Center(child: Text(e.toString(), style: widget.textStyle ?? TextStyle(fontSize: 24, color: NUIColors.NUIWhite)));
                      }).toList()
                  ),
                ),
                Expanded(
                  child: CupertinoPicker(
                      scrollController: FixedExtentScrollController(initialItem: curMonthIndex),
                      itemExtent: widget.itemExtent,
                      magnification: 1,
                      onSelectedItemChanged: (position){
                        setState(() {
                          _prevSelectedMonth = _selectedMonth;
                          _selectedMonth = position + 1;
                          _updateSelectedDayOnMonthChange();
                          widget.controller._valueChanged();
                        });
                      },
                      children: (widget.shortMonth == true ? DOBPicker.MONTHS_SHORT : DOBPicker.MONTHS).map((e) {
                        return Center(child: Text(e.toString(), style: widget.textStyle ?? TextStyle(fontSize: 24, color: NUIColors.NUIWhite)));
                      }).toList()
                  ),
                ),
                Expanded(
                  child: CupertinoPicker(
                      scrollController: FixedExtentScrollController(initialItem: curYearIndex),
                      itemExtent: widget.itemExtent,
                      magnification: 1,
                      onSelectedItemChanged: (position){
                        setState(() {
                          _prevSelectedYear = _selectedYear;
                          _selectedYear = yearsSelection[position];
                          _updateSelectedDayOnMonthChange();
                          widget.controller._valueChanged();
                        });
                      },
                      children: yearsSelection.map((e) {
                        return Center(child: Text(e.toString(), style: widget.textStyle ?? TextStyle(fontSize: 24, color: NUIColors.NUIWhite)));
                      }).toList()
                  ),
                ),
              ],
            ),
          ),
          Container(
            margin: EdgeInsets.only(top: (widget.height - widget.itemExtent)/2),
            width: double.infinity,
            height: 1,
            color: widget.lineColor ?? NUIColors.NUIWhite.withOpacity(0.5),
          ),
          Container(
            margin: EdgeInsets.only(top: widget.height - (widget.height - widget.itemExtent)/2),
            width: double.infinity,
            height: 1,
            color: widget.lineColor ?? NUIColors.NUIWhite.withOpacity(0.5),
          )
        ],
      ),
    );
  }
}
